Match

Struct Match 

pub struct Match {
    pub start: usize,
    pub end: usize,
}
a single match result, representing a byte-offset range [start, end).

Fields

start: usize

byte offset of the start of the match (inclusive).

end: usize

byte offset of the end of the match (exclusive).