pub struct Match {
pub start: usize,
pub end: usize,
}Expand description
a single match result, representing a byte-offset range [start, end).
Fields
start: usizebyte offset of the start of the match (inclusive).
end: usizebyte offset of the end of the match (exclusive).